# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/service/service_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.common_config import parameters_pb2 as prodvana_dot_common__config_dot_parameters__pb2
from prodvana.proto.prodvana.convergence import convergence_mode_pb2 as prodvana_dot_convergence_dot_convergence__mode__pb2
from prodvana.proto.prodvana.service import parameters_pb2 as prodvana_dot_service_dot_parameters__pb2
from prodvana.proto.prodvana.service import service_config_pb2 as prodvana_dot_service_dot_service__config__pb2
from prodvana.proto.prodvana.service import user_metadata_pb2 as prodvana_dot_service_dot_user__metadata__pb2
from prodvana.proto.prodvana.service import object_pb2 as prodvana_dot_service_dot_object__pb2
from prodvana.proto.prodvana.stat import efficiency_pb2 as prodvana_dot_stat_dot_efficiency__pb2
from prodvana.proto.prodvana.metrics import metrics_pb2 as prodvana_dot_metrics_dot_metrics__pb2
from prodvana.proto.prodvana.insights import insights_pb2 as prodvana_dot_insights_dot_insights__pb2
from prodvana.proto.prodvana.repo import repo_pb2 as prodvana_dot_repo_dot_repo__pb2
from prodvana.proto.prodvana.version import source_metadata_pb2 as prodvana_dot_version_dot_source__metadata__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&prodvana/service/service_manager.proto\x12\x10prodvana.service\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'prodvana/common_config/parameters.proto\x1a+prodvana/convergence/convergence_mode.proto\x1a!prodvana/service/parameters.proto\x1a%prodvana/service/service_config.proto\x1a$prodvana/service/user_metadata.proto\x1a\x1dprodvana/service/object.proto\x1a\x1eprodvana/stat/efficiency.proto\x1a\x1eprodvana/metrics/metrics.proto\x1a prodvana/insights/insights.proto\x1a\x18prodvana/repo/repo.proto\x1a&prodvana/version/source_metadata.proto\x1a\x17validate/validate.proto\"w\n\x1dServiceConfigVersionReference\x12\x13\n\x0b\x61pplication\x18\x01 \x01(\t\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\'\n\x16service_config_version\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xa8\x02\n\x16GenerateVersionNameReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\'\n\x16service_config_version\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12I\n\nparameters\x18\x04 \x03(\x0b\x32&.prodvana.common_config.ParameterValueB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12\x62\n\x13per_release_channel\x18\x05 \x03(\x0b\x32\x36.prodvana.service.ApplyParametersReq.PerReleaseChannelB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\"*\n\x17GenerateVersionNameResp\x12\x0f\n\x07version\x18\x01 \x01(\t\"\x9a\x06\n\x12\x41pplyParametersReq\x12\x39\n\x0eservice_config\x18\x01 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfigH\x00\x12Q\n\x16service_config_version\x18\x08 \x01(\x0b\x32/.prodvana.service.ServiceConfigVersionReferenceH\x00\x12I\n\nparameters\x18\t \x03(\x0b\x32&.prodvana.common_config.ParameterValueB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12\x62\n\x13per_release_channel\x18\n \x03(\x0b\x32\x36.prodvana.service.ApplyParametersReq.PerReleaseChannelB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12%\n\x1dtest_only_skip_registry_check\x18\x04 \x01(\x08\x12\x13\n\x0b\x61pplication\x18\x05 \x01(\t\x12(\n\x06source\x18\x06 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x07 \x01(\x0b\x32 .prodvana.version.SourceMetadata\x12\x1c\n\x14\x62undle_name_override\x18\x0b \x01(\t\x12$\n\x1chandle_bundle_name_duplicate\x18\r \x01(\x08\x12\x1f\n\x17skip_runtime_validation\x18\x0c \x01(\x08\x1a\x80\x01\n\x11PerReleaseChannel\x12 \n\x0frelease_channel\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12I\n\nparameters\x18\x02 \x03(\x0b\x32&.prodvana.common_config.ParameterValueB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x42\x0c\n\x05oneof\x12\x03\xf8\x42\x01J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04R\x10release_channelsR\x12\x63ompute_efficiency\"r\n\x13\x41pplyParametersResp\x12\x12\n\nservice_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x36\n\x0f\x65\x66\x66iciency_stat\x18\x03 \x01(\x0b\x32\x1d.prodvana.stat.EfficiencyStat\"\xf9\x01\n\x1bValidateApplyParametersResp\x12/\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12\x38\n\x0f\x63ompiled_config\x18\x02 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12\x13\n\x0b\x61pp_version\x18\x03 \x01(\t\x12Z\n!compiled_service_instance_configs\x18\x04 \x03(\x0b\x32/.prodvana.service.CompiledServiceInstanceConfig\"Z\n\x18GetMaterializedConfigReq\x12\x18\n\x07service\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x13\n\x0b\x61pplication\x18\x03 \x01(\t\"\xd3\x02\n\x19GetMaterializedConfigResp\x12/\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x38\n\x0f\x63ompiled_config\x18\x03 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12Z\n!compiled_service_instance_configs\x18\x04 \x03(\x0b\x32/.prodvana.service.CompiledServiceInstanceConfig\x12^\n\x10version_metadata\x18\x05 \x01(\x0b\x32\x44.prodvana.service.ListMaterializedConfigVersionsResp.VersionMetadata\"A\n\x10\x44\x65leteServiceReq\x12\x18\n\x07service\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x13\n\x0b\x61pplication\x18\x02 \x01(\t\"\x13\n\x11\x44\x65leteServiceResp\"A\n\x0fListServicesReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x10\n\x08\x64\x65tailed\x18\x02 \x01(\x08\"?\n\x10ListServicesResp\x12+\n\x08services\x18\x01 \x03(\x0b\x32\x19.prodvana.service.Service\"G\n\rGetServiceReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"<\n\x0eGetServiceResp\x12*\n\x07service\x18\x01 \x01(\x0b\x32\x19.prodvana.service.Service\"Q\n\x17ListServiceInstancesReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"X\n\x18ListServiceInstancesResp\x12<\n\x11service_instances\x18\x01 \x03(\x0b\x32!.prodvana.service.ServiceInstance\"q\n\x15GetServiceInstanceReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12 \n\x0frelease_channel\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"U\n\x16GetServiceInstanceResp\x12;\n\x10service_instance\x18\x01 \x01(\x0b\x32!.prodvana.service.ServiceInstance\"\xcc\x01\n\x14GetServiceMetricsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x33\n\x0fstart_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0cinclude_cost\x18\x05 \x01(\x08\"~\n\x15GetServiceMetricsResp\x12?\n\x12\x64\x65ployment_metrics\x18\x01 \x01(\x0b\x32#.prodvana.metrics.DeploymentMetrics\x12$\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x16.prodvana.metrics.Cost\"O\n\x15GetServiceInsightsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"o\n\x0eListCommitsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"R\n\x0fListCommitsResp\x12&\n\x07\x63ommits\x18\x01 \x03(\x0b\x32\x15.prodvana.repo.Commit\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"F\n\x16GetServiceInsightsResp\x12,\n\x08insights\x18\x01 \x03(\x0b\x32\x1a.prodvana.insights.Insight\"\xbd\x01\n\x17SnoozeServiceInsightReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x31\n\x05\x63lass\x18\x03 \x01(\x0e\x32\x18.prodvana.insights.ClassB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x37\n\x08\x64uration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\"\x1a\n\x18SnoozeServiceInsightResp\"O\n\x15GetServiceMetadataReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"Q\n\x16GetServiceMetadataResp\x12\x37\n\x08metadata\x18\x01 \x01(\x0b\x32%.prodvana.service.ServiceUserMetadata\"\x92\x01\n\x15SetServiceMetadataReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x41\n\x08metadata\x18\x03 \x01(\x0b\x32%.prodvana.service.ServiceUserMetadataB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x18\n\x16SetServiceMetadataResp\"\x97\x01\n\x1cSetServiceConvergenceModeReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12?\n\x10\x63onvergence_mode\x18\x03 \x01(\x0e\x32%.prodvana.convergence.ConvergenceMode\"\x1f\n\x1dSetServiceConvergenceModeResp\"\x82\x01\n!ListMaterializedConfigVersionsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"\x89\x04\n\"ListMaterializedConfigVersionsResp\x12V\n\x08versions\x18\x01 \x03(\x0b\x32\x44.prodvana.service.ListMaterializedConfigVersionsResp.VersionMetadata\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a\xf1\x02\n\x0fVersionMetadata\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0e\x63onfig_version\x18\x03 \x01(\t\x12?\n\nparameters\x18\x07 \x03(\x0b\x32+.prodvana.common_config.ParameterDefinition\x12\x42\n\x10parameter_values\x18\x04 \x01(\x0b\x32(.prodvana.service.ServiceParameterValues\x12(\n\x06source\x18\x05 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x06 \x01(\x0b\x32 .prodvana.version.SourceMetadata\x12\x13\n\x0b\x61pp_version\x18\x08 \x01(\t\"\xbc\x02\n\x13\x43onfigureServiceReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x41\n\x0eservice_config\x18\x02 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12(\n\x06source\x18\x03 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x04 \x01(\x0b\x32 .prodvana.version.SourceMetadata\x12\x1c\n\x14\x62undle_name_override\x18\x05 \x01(\t\x12\x1f\n\x17skip_runtime_validation\x18\x06 \x01(\x08\x12 \n\x18\x66orce_create_new_version\x18\x07 \x01(\x08\"_\n\x14\x43onfigureServiceResp\x12\x12\n\nservice_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63onfig_version\x18\x02 \x01(\t\x12\x1b\n\x13\x63reated_new_version\x18\x03 \x01(\x08\"\x8f\x01\n\x1cValidateConfigureServiceResp\x12\x35\n\x0cinput_config\x18\x01 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12\x38\n\x0f\x63ompiled_config\x18\x02 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\"}\n\x1cListServiceConfigVersionsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"\xcd\x02\n\x1dListServiceConfigVersionsResp\x12Q\n\x08versions\x18\x01 \x03(\x0b\x32?.prodvana.service.ListServiceConfigVersionsResp.VersionMetadata\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a\xbf\x01\n\x0fVersionMetadata\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x06source\x18\x03 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x04 \x01(\x0b\x32 .prodvana.version.SourceMetadata\"e\n\x13GetServiceConfigReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x0e\x63onfig_version\x18\x03 \x01(\t\"\xb2\x02\n\x14GetServiceConfigResp\x12/\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12\x35\n\x0cinput_config\x18\x04 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12\x38\n\x0f\x63ompiled_config\x18\x05 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12\x16\n\x0e\x63onfig_version\x18\x02 \x01(\t\x12`\n\x17\x63onfig_version_metadata\x18\x03 \x01(\x0b\x32?.prodvana.service.ListServiceConfigVersionsResp.VersionMetadata2\x85\x1d\n\x0eServiceManager\x12\x95\x01\n\x10\x43onfigureService\x12%.prodvana.service.ConfigureServiceReq\x1a&.prodvana.service.ConfigureServiceResp\"2\x82\xd3\xe4\x93\x02,\"\'/v1/{application=*}/services/configure2:\x01*\x12\xad\x01\n\x18ValidateConfigureService\x12%.prodvana.service.ConfigureServiceReq\x1a..prodvana.service.ValidateConfigureServiceResp\":\x82\xd3\xe4\x93\x02\x34\"//v1/{application=*}/services/configure/validate:\x01*\x12\xbe\x01\n\x19ListServiceConfigVersions\x12..prodvana.service.ListServiceConfigVersionsReq\x1a/.prodvana.service.ListServiceConfigVersionsResp\"@\x82\xd3\xe4\x93\x02:\x12\x38/v1/{application=*}/services/{service=*}/config/versions\x12\x9a\x01\n\x10GetServiceConfig\x12%.prodvana.service.GetServiceConfigReq\x1a&.prodvana.service.GetServiceConfigResp\"7\x82\xd3\xe4\x93\x02\x31\x12//v1/{application=*}/services/{service=*}/config\x12\xb5\x01\n\x13GenerateVersionName\x12(.prodvana.service.GenerateVersionNameReq\x1a).prodvana.service.GenerateVersionNameResp\"I\x82\xd3\xe4\x93\x02\x43\">/v1/{application=*}/services/{service=*}/generate-version-name:\x01*\x12\x98\x01\n\x0f\x41pplyParameters\x12$.prodvana.service.ApplyParametersReq\x1a%.prodvana.service.ApplyParametersResp\"8\x82\xd3\xe4\x93\x02\x32\"-/v1/{application=*}/services/apply-parameters:\x01*\x12\xb1\x01\n\x17ValidateApplyParameters\x12$.prodvana.service.ApplyParametersReq\x1a-.prodvana.service.ValidateApplyParametersResp\"A\x82\xd3\xe4\x93\x02;\"6/v1/{application=*}/services/apply-parameters/validate:\x01*\x12\xb6\x01\n\x15GetMaterializedConfig\x12*.prodvana.service.GetMaterializedConfigReq\x1a+.prodvana.service.GetMaterializedConfigResp\"D\x82\xd3\xe4\x93\x02>\x12</v1/{application=*}/services/{service=*}/materialized/config\x12\xda\x01\n\x1eListMaterializedConfigVersions\x12\x33.prodvana.service.ListMaterializedConfigVersionsReq\x1a\x34.prodvana.service.ListMaterializedConfigVersionsResp\"M\x82\xd3\xe4\x93\x02G\x12\x45/v1/{application=*}/services/{service=*}/materialized/config/versions\x12\x91\x01\n\rDeleteService\x12\".prodvana.service.DeleteServiceReq\x1a#.prodvana.service.DeleteServiceResp\"7\x82\xd3\xe4\x93\x02\x31*//v1/{application=*}/services/{service=*}/delete\x12\x88\x01\n\x0cListServices\x12!.prodvana.service.ListServicesReq\x1a\".prodvana.service.ListServicesResp\"1\x82\xd3\xe4\x93\x02+\x12)/v1/applications/{application=*}/services\x12\x99\x01\n\x0bListCommits\x12 .prodvana.service.ListCommitsReq\x1a!.prodvana.service.ListCommitsResp\"E\x82\xd3\xe4\x93\x02?\x12=/v1/applications/{application=*}/services/{service=*}/commits\x12\x8e\x01\n\nGetService\x12\x1f.prodvana.service.GetServiceReq\x1a .prodvana.service.GetServiceResp\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/v1/applications/{application=*}/services/{service=*}\x12\xbd\x01\n\x14ListServiceInstances\x12).prodvana.service.ListServiceInstancesReq\x1a*.prodvana.service.ListServiceInstancesResp\"N\x82\xd3\xe4\x93\x02H\x12\x46/v1/applications/{application=*}/services/{service=*}/release-channels\x12\xcb\x01\n\x12GetServiceInstance\x12\'.prodvana.service.GetServiceInstanceReq\x1a(.prodvana.service.GetServiceInstanceResp\"b\x82\xd3\xe4\x93\x02\\\x12Z/v1/applications/{application=*}/services/{service=*}/release-channels/{release_channel=*}\x12\xab\x01\n\x11GetServiceMetrics\x12&.prodvana.service.GetServiceMetricsReq\x1a\'.prodvana.service.GetServiceMetricsResp\"E\x82\xd3\xe4\x93\x02?\x12=/v1/applications/{application=*}/services/{service=*}/metrics\x12\xaf\x01\n\x12GetServiceInsights\x12\'.prodvana.service.GetServiceInsightsReq\x1a(.prodvana.service.GetServiceInsightsResp\"F\x82\xd3\xe4\x93\x02@\x12>/v1/applications/{application=*}/services/{service=*}/insights\x12\xbc\x01\n\x14SnoozeServiceInsight\x12).prodvana.service.SnoozeServiceInsightReq\x1a*.prodvana.service.SnoozeServiceInsightResp\"M\x82\xd3\xe4\x93\x02G\x1a\x45/v1/applications/{application=*}/services/{service=*}/insights/snooze\x12\xaf\x01\n\x12GetServiceMetadata\x12\'.prodvana.service.GetServiceMetadataReq\x1a(.prodvana.service.GetServiceMetadataResp\"F\x82\xd3\xe4\x93\x02@\x12>/v1/applications/{application=*}/services/{service=*}/metadata\x12\xb2\x01\n\x12SetServiceMetadata\x12\'.prodvana.service.SetServiceMetadataReq\x1a(.prodvana.service.SetServiceMetadataResp\"I\x82\xd3\xe4\x93\x02\x43\">/v1/applications/{application=*}/services/{service=*}/metadata:\x01*\x12\xcf\x01\n\x19SetServiceConvergenceMode\x12..prodvana.service.SetServiceConvergenceModeReq\x1a/.prodvana.service.SetServiceConvergenceModeResp\"Q\x82\xd3\xe4\x93\x02K\"F/v1/applications/{application=*}/services/{service=*}/convergence-mode:\x01*BLZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/serviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.service.service_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/service'
  _SERVICECONFIGVERSIONREFERENCE.fields_by_name['service']._options = None
  _SERVICECONFIGVERSIONREFERENCE.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SERVICECONFIGVERSIONREFERENCE.fields_by_name['service_config_version']._options = None
  _SERVICECONFIGVERSIONREFERENCE.fields_by_name['service_config_version']._serialized_options = b'\372B\004r\002\020\001'
  _GENERATEVERSIONNAMEREQ.fields_by_name['application']._options = None
  _GENERATEVERSIONNAMEREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GENERATEVERSIONNAMEREQ.fields_by_name['service']._options = None
  _GENERATEVERSIONNAMEREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GENERATEVERSIONNAMEREQ.fields_by_name['service_config_version']._options = None
  _GENERATEVERSIONNAMEREQ.fields_by_name['service_config_version']._serialized_options = b'\372B\004r\002\020\001'
  _GENERATEVERSIONNAMEREQ.fields_by_name['parameters']._options = None
  _GENERATEVERSIONNAMEREQ.fields_by_name['parameters']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _GENERATEVERSIONNAMEREQ.fields_by_name['per_release_channel']._options = None
  _GENERATEVERSIONNAMEREQ.fields_by_name['per_release_channel']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _APPLYPARAMETERSREQ_PERRELEASECHANNEL.fields_by_name['release_channel']._options = None
  _APPLYPARAMETERSREQ_PERRELEASECHANNEL.fields_by_name['release_channel']._serialized_options = b'\372B\004r\002\020\001'
  _APPLYPARAMETERSREQ_PERRELEASECHANNEL.fields_by_name['parameters']._options = None
  _APPLYPARAMETERSREQ_PERRELEASECHANNEL.fields_by_name['parameters']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _APPLYPARAMETERSREQ.oneofs_by_name['oneof']._options = None
  _APPLYPARAMETERSREQ.oneofs_by_name['oneof']._serialized_options = b'\370B\001'
  _APPLYPARAMETERSREQ.fields_by_name['parameters']._options = None
  _APPLYPARAMETERSREQ.fields_by_name['parameters']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _APPLYPARAMETERSREQ.fields_by_name['per_release_channel']._options = None
  _APPLYPARAMETERSREQ.fields_by_name['per_release_channel']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _GETMATERIALIZEDCONFIGREQ.fields_by_name['service']._options = None
  _GETMATERIALIZEDCONFIGREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _DELETESERVICEREQ.fields_by_name['service']._options = None
  _DELETESERVICEREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _LISTSERVICESREQ.fields_by_name['application']._options = None
  _LISTSERVICESREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEREQ.fields_by_name['application']._options = None
  _GETSERVICEREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEREQ.fields_by_name['service']._options = None
  _GETSERVICEREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _LISTSERVICEINSTANCESREQ.fields_by_name['application']._options = None
  _LISTSERVICEINSTANCESREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _LISTSERVICEINSTANCESREQ.fields_by_name['service']._options = None
  _LISTSERVICEINSTANCESREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEINSTANCEREQ.fields_by_name['application']._options = None
  _GETSERVICEINSTANCEREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEINSTANCEREQ.fields_by_name['service']._options = None
  _GETSERVICEINSTANCEREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEINSTANCEREQ.fields_by_name['release_channel']._options = None
  _GETSERVICEINSTANCEREQ.fields_by_name['release_channel']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEMETRICSREQ.fields_by_name['application']._options = None
  _GETSERVICEMETRICSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEMETRICSREQ.fields_by_name['service']._options = None
  _GETSERVICEMETRICSREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEINSIGHTSREQ.fields_by_name['application']._options = None
  _GETSERVICEINSIGHTSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEINSIGHTSREQ.fields_by_name['service']._options = None
  _GETSERVICEINSIGHTSREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _LISTCOMMITSREQ.fields_by_name['application']._options = None
  _LISTCOMMITSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _LISTCOMMITSREQ.fields_by_name['service']._options = None
  _LISTCOMMITSREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['application']._options = None
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['service']._options = None
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['class']._options = None
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['class']._serialized_options = b'\372B\005\202\001\002\020\001'
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['duration']._options = None
  _SNOOZESERVICEINSIGHTREQ.fields_by_name['duration']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _GETSERVICEMETADATAREQ.fields_by_name['application']._options = None
  _GETSERVICEMETADATAREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEMETADATAREQ.fields_by_name['service']._options = None
  _GETSERVICEMETADATAREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SETSERVICEMETADATAREQ.fields_by_name['application']._options = None
  _SETSERVICEMETADATAREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _SETSERVICEMETADATAREQ.fields_by_name['service']._options = None
  _SETSERVICEMETADATAREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SETSERVICEMETADATAREQ.fields_by_name['metadata']._options = None
  _SETSERVICEMETADATAREQ.fields_by_name['metadata']._serialized_options = b'\372B\005\212\001\002\020\001'
  _SETSERVICECONVERGENCEMODEREQ.fields_by_name['application']._options = None
  _SETSERVICECONVERGENCEMODEREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _SETSERVICECONVERGENCEMODEREQ.fields_by_name['service']._options = None
  _SETSERVICECONVERGENCEMODEREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _LISTMATERIALIZEDCONFIGVERSIONSREQ.fields_by_name['application']._options = None
  _LISTMATERIALIZEDCONFIGVERSIONSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _LISTMATERIALIZEDCONFIGVERSIONSREQ.fields_by_name['service']._options = None
  _LISTMATERIALIZEDCONFIGVERSIONSREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _CONFIGURESERVICEREQ.fields_by_name['application']._options = None
  _CONFIGURESERVICEREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _CONFIGURESERVICEREQ.fields_by_name['service_config']._options = None
  _CONFIGURESERVICEREQ.fields_by_name['service_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTSERVICECONFIGVERSIONSREQ.fields_by_name['application']._options = None
  _LISTSERVICECONFIGVERSIONSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _LISTSERVICECONFIGVERSIONSREQ.fields_by_name['service']._options = None
  _LISTSERVICECONFIGVERSIONSREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICECONFIGREQ.fields_by_name['application']._options = None
  _GETSERVICECONFIGREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICECONFIGREQ.fields_by_name['service']._options = None
  _GETSERVICECONFIGREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SERVICEMANAGER.methods_by_name['ConfigureService']._options = None
  _SERVICEMANAGER.methods_by_name['ConfigureService']._serialized_options = b'\202\323\344\223\002,\"\'/v1/{application=*}/services/configure2:\001*'
  _SERVICEMANAGER.methods_by_name['ValidateConfigureService']._options = None
  _SERVICEMANAGER.methods_by_name['ValidateConfigureService']._serialized_options = b'\202\323\344\223\0024\"//v1/{application=*}/services/configure/validate:\001*'
  _SERVICEMANAGER.methods_by_name['ListServiceConfigVersions']._options = None
  _SERVICEMANAGER.methods_by_name['ListServiceConfigVersions']._serialized_options = b'\202\323\344\223\002:\0228/v1/{application=*}/services/{service=*}/config/versions'
  _SERVICEMANAGER.methods_by_name['GetServiceConfig']._options = None
  _SERVICEMANAGER.methods_by_name['GetServiceConfig']._serialized_options = b'\202\323\344\223\0021\022//v1/{application=*}/services/{service=*}/config'
  _SERVICEMANAGER.methods_by_name['GenerateVersionName']._options = None
  _SERVICEMANAGER.methods_by_name['GenerateVersionName']._serialized_options = b'\202\323\344\223\002C\">/v1/{application=*}/services/{service=*}/generate-version-name:\001*'
  _SERVICEMANAGER.methods_by_name['ApplyParameters']._options = None
  _SERVICEMANAGER.methods_by_name['ApplyParameters']._serialized_options = b'\202\323\344\223\0022\"-/v1/{application=*}/services/apply-parameters:\001*'
  _SERVICEMANAGER.methods_by_name['ValidateApplyParameters']._options = None
  _SERVICEMANAGER.methods_by_name['ValidateApplyParameters']._serialized_options = b'\202\323\344\223\002;\"6/v1/{application=*}/services/apply-parameters/validate:\001*'
  _SERVICEMANAGER.methods_by_name['GetMaterializedConfig']._options = None
  _SERVICEMANAGER.methods_by_name['GetMaterializedConfig']._serialized_options = b'\202\323\344\223\002>\022</v1/{application=*}/services/{service=*}/materialized/config'
  _SERVICEMANAGER.methods_by_name['ListMaterializedConfigVersions']._options = None
  _SERVICEMANAGER.methods_by_name['ListMaterializedConfigVersions']._serialized_options = b'\202\323\344\223\002G\022E/v1/{application=*}/services/{service=*}/materialized/config/versions'
  _SERVICEMANAGER.methods_by_name['DeleteService']._options = None
  _SERVICEMANAGER.methods_by_name['DeleteService']._serialized_options = b'\202\323\344\223\0021*//v1/{application=*}/services/{service=*}/delete'
  _SERVICEMANAGER.methods_by_name['ListServices']._options = None
  _SERVICEMANAGER.methods_by_name['ListServices']._serialized_options = b'\202\323\344\223\002+\022)/v1/applications/{application=*}/services'
  _SERVICEMANAGER.methods_by_name['ListCommits']._options = None
  _SERVICEMANAGER.methods_by_name['ListCommits']._serialized_options = b'\202\323\344\223\002?\022=/v1/applications/{application=*}/services/{service=*}/commits'
  _SERVICEMANAGER.methods_by_name['GetService']._options = None
  _SERVICEMANAGER.methods_by_name['GetService']._serialized_options = b'\202\323\344\223\0027\0225/v1/applications/{application=*}/services/{service=*}'
  _SERVICEMANAGER.methods_by_name['ListServiceInstances']._options = None
  _SERVICEMANAGER.methods_by_name['ListServiceInstances']._serialized_options = b'\202\323\344\223\002H\022F/v1/applications/{application=*}/services/{service=*}/release-channels'
  _SERVICEMANAGER.methods_by_name['GetServiceInstance']._options = None
  _SERVICEMANAGER.methods_by_name['GetServiceInstance']._serialized_options = b'\202\323\344\223\002\\\022Z/v1/applications/{application=*}/services/{service=*}/release-channels/{release_channel=*}'
  _SERVICEMANAGER.methods_by_name['GetServiceMetrics']._options = None
  _SERVICEMANAGER.methods_by_name['GetServiceMetrics']._serialized_options = b'\202\323\344\223\002?\022=/v1/applications/{application=*}/services/{service=*}/metrics'
  _SERVICEMANAGER.methods_by_name['GetServiceInsights']._options = None
  _SERVICEMANAGER.methods_by_name['GetServiceInsights']._serialized_options = b'\202\323\344\223\002@\022>/v1/applications/{application=*}/services/{service=*}/insights'
  _SERVICEMANAGER.methods_by_name['SnoozeServiceInsight']._options = None
  _SERVICEMANAGER.methods_by_name['SnoozeServiceInsight']._serialized_options = b'\202\323\344\223\002G\032E/v1/applications/{application=*}/services/{service=*}/insights/snooze'
  _SERVICEMANAGER.methods_by_name['GetServiceMetadata']._options = None
  _SERVICEMANAGER.methods_by_name['GetServiceMetadata']._serialized_options = b'\202\323\344\223\002@\022>/v1/applications/{application=*}/services/{service=*}/metadata'
  _SERVICEMANAGER.methods_by_name['SetServiceMetadata']._options = None
  _SERVICEMANAGER.methods_by_name['SetServiceMetadata']._serialized_options = b'\202\323\344\223\002C\">/v1/applications/{application=*}/services/{service=*}/metadata:\001*'
  _SERVICEMANAGER.methods_by_name['SetServiceConvergenceMode']._options = None
  _SERVICEMANAGER.methods_by_name['SetServiceConvergenceMode']._serialized_options = b'\202\323\344\223\002K\"F/v1/applications/{application=*}/services/{service=*}/convergence-mode:\001*'
  _globals['_SERVICECONFIGVERSIONREFERENCE']._serialized_start=573
  _globals['_SERVICECONFIGVERSIONREFERENCE']._serialized_end=692
  _globals['_GENERATEVERSIONNAMEREQ']._serialized_start=695
  _globals['_GENERATEVERSIONNAMEREQ']._serialized_end=991
  _globals['_GENERATEVERSIONNAMERESP']._serialized_start=993
  _globals['_GENERATEVERSIONNAMERESP']._serialized_end=1035
  _globals['_APPLYPARAMETERSREQ']._serialized_start=1038
  _globals['_APPLYPARAMETERSREQ']._serialized_end=1832
  _globals['_APPLYPARAMETERSREQ_PERRELEASECHANNEL']._serialized_start=1640
  _globals['_APPLYPARAMETERSREQ_PERRELEASECHANNEL']._serialized_end=1768
  _globals['_APPLYPARAMETERSRESP']._serialized_start=1834
  _globals['_APPLYPARAMETERSRESP']._serialized_end=1948
  _globals['_VALIDATEAPPLYPARAMETERSRESP']._serialized_start=1951
  _globals['_VALIDATEAPPLYPARAMETERSRESP']._serialized_end=2200
  _globals['_GETMATERIALIZEDCONFIGREQ']._serialized_start=2202
  _globals['_GETMATERIALIZEDCONFIGREQ']._serialized_end=2292
  _globals['_GETMATERIALIZEDCONFIGRESP']._serialized_start=2295
  _globals['_GETMATERIALIZEDCONFIGRESP']._serialized_end=2634
  _globals['_DELETESERVICEREQ']._serialized_start=2636
  _globals['_DELETESERVICEREQ']._serialized_end=2701
  _globals['_DELETESERVICERESP']._serialized_start=2703
  _globals['_DELETESERVICERESP']._serialized_end=2722
  _globals['_LISTSERVICESREQ']._serialized_start=2724
  _globals['_LISTSERVICESREQ']._serialized_end=2789
  _globals['_LISTSERVICESRESP']._serialized_start=2791
  _globals['_LISTSERVICESRESP']._serialized_end=2854
  _globals['_GETSERVICEREQ']._serialized_start=2856
  _globals['_GETSERVICEREQ']._serialized_end=2927
  _globals['_GETSERVICERESP']._serialized_start=2929
  _globals['_GETSERVICERESP']._serialized_end=2989
  _globals['_LISTSERVICEINSTANCESREQ']._serialized_start=2991
  _globals['_LISTSERVICEINSTANCESREQ']._serialized_end=3072
  _globals['_LISTSERVICEINSTANCESRESP']._serialized_start=3074
  _globals['_LISTSERVICEINSTANCESRESP']._serialized_end=3162
  _globals['_GETSERVICEINSTANCEREQ']._serialized_start=3164
  _globals['_GETSERVICEINSTANCEREQ']._serialized_end=3277
  _globals['_GETSERVICEINSTANCERESP']._serialized_start=3279
  _globals['_GETSERVICEINSTANCERESP']._serialized_end=3364
  _globals['_GETSERVICEMETRICSREQ']._serialized_start=3367
  _globals['_GETSERVICEMETRICSREQ']._serialized_end=3571
  _globals['_GETSERVICEMETRICSRESP']._serialized_start=3573
  _globals['_GETSERVICEMETRICSRESP']._serialized_end=3699
  _globals['_GETSERVICEINSIGHTSREQ']._serialized_start=3701
  _globals['_GETSERVICEINSIGHTSREQ']._serialized_end=3780
  _globals['_LISTCOMMITSREQ']._serialized_start=3782
  _globals['_LISTCOMMITSREQ']._serialized_end=3893
  _globals['_LISTCOMMITSRESP']._serialized_start=3895
  _globals['_LISTCOMMITSRESP']._serialized_end=3977
  _globals['_GETSERVICEINSIGHTSRESP']._serialized_start=3979
  _globals['_GETSERVICEINSIGHTSRESP']._serialized_end=4049
  _globals['_SNOOZESERVICEINSIGHTREQ']._serialized_start=4052
  _globals['_SNOOZESERVICEINSIGHTREQ']._serialized_end=4241
  _globals['_SNOOZESERVICEINSIGHTRESP']._serialized_start=4243
  _globals['_SNOOZESERVICEINSIGHTRESP']._serialized_end=4269
  _globals['_GETSERVICEMETADATAREQ']._serialized_start=4271
  _globals['_GETSERVICEMETADATAREQ']._serialized_end=4350
  _globals['_GETSERVICEMETADATARESP']._serialized_start=4352
  _globals['_GETSERVICEMETADATARESP']._serialized_end=4433
  _globals['_SETSERVICEMETADATAREQ']._serialized_start=4436
  _globals['_SETSERVICEMETADATAREQ']._serialized_end=4582
  _globals['_SETSERVICEMETADATARESP']._serialized_start=4584
  _globals['_SETSERVICEMETADATARESP']._serialized_end=4608
  _globals['_SETSERVICECONVERGENCEMODEREQ']._serialized_start=4611
  _globals['_SETSERVICECONVERGENCEMODEREQ']._serialized_end=4762
  _globals['_SETSERVICECONVERGENCEMODERESP']._serialized_start=4764
  _globals['_SETSERVICECONVERGENCEMODERESP']._serialized_end=4795
  _globals['_LISTMATERIALIZEDCONFIGVERSIONSREQ']._serialized_start=4798
  _globals['_LISTMATERIALIZEDCONFIGVERSIONSREQ']._serialized_end=4928
  _globals['_LISTMATERIALIZEDCONFIGVERSIONSRESP']._serialized_start=4931
  _globals['_LISTMATERIALIZEDCONFIGVERSIONSRESP']._serialized_end=5452
  _globals['_LISTMATERIALIZEDCONFIGVERSIONSRESP_VERSIONMETADATA']._serialized_start=5083
  _globals['_LISTMATERIALIZEDCONFIGVERSIONSRESP_VERSIONMETADATA']._serialized_end=5452
  _globals['_CONFIGURESERVICEREQ']._serialized_start=5455
  _globals['_CONFIGURESERVICEREQ']._serialized_end=5771
  _globals['_CONFIGURESERVICERESP']._serialized_start=5773
  _globals['_CONFIGURESERVICERESP']._serialized_end=5868
  _globals['_VALIDATECONFIGURESERVICERESP']._serialized_start=5871
  _globals['_VALIDATECONFIGURESERVICERESP']._serialized_end=6014
  _globals['_LISTSERVICECONFIGVERSIONSREQ']._serialized_start=6016
  _globals['_LISTSERVICECONFIGVERSIONSREQ']._serialized_end=6141
  _globals['_LISTSERVICECONFIGVERSIONSRESP']._serialized_start=6144
  _globals['_LISTSERVICECONFIGVERSIONSRESP']._serialized_end=6477
  _globals['_LISTSERVICECONFIGVERSIONSRESP_VERSIONMETADATA']._serialized_start=6286
  _globals['_LISTSERVICECONFIGVERSIONSRESP_VERSIONMETADATA']._serialized_end=6477
  _globals['_GETSERVICECONFIGREQ']._serialized_start=6479
  _globals['_GETSERVICECONFIGREQ']._serialized_end=6580
  _globals['_GETSERVICECONFIGRESP']._serialized_start=6583
  _globals['_GETSERVICECONFIGRESP']._serialized_end=6889
  _globals['_SERVICEMANAGER']._serialized_start=6892
  _globals['_SERVICEMANAGER']._serialized_end=10609
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/external_link.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*prodvana/common_config/external_link.proto\x12\x16prodvana.common_config\x1a\x17validate/validate.proto\"\xa6\x01\n\x0c\x45xternalLink\x12;\n\x04type\x18\x01 \x01(\x0e\x32-.prodvana.common_config.ExternalLink.LinkType\x12\x14\n\x03url\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x04name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\",\n\x08LinkType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x44\x45TAIL\x10\x01\x12\x07\n\x03LOG\x10\x02\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.common_config.external_link_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _EXTERNALLINK.fields_by_name['url']._options = None
  _EXTERNALLINK.fields_by_name['url']._serialized_options = b'\372B\004r\002\020\001'
  _EXTERNALLINK.fields_by_name['name']._options = None
  _EXTERNALLINK.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_EXTERNALLINK']._serialized_start=96
  _globals['_EXTERNALLINK']._serialized_end=262
  _globals['_EXTERNALLINK_LINKTYPE']._serialized_start=218
  _globals['_EXTERNALLINK_LINKTYPE']._serialized_end=262
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.capability.capability_pb2
import prodvana.proto.prodvana.common_config.notification_pb2
import prodvana.proto.prodvana.release_channel.release_channel_config_pb2
import prodvana.proto.prodvana.workflow.integration_config_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AnnotationsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Last9(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DATA_SOURCE_FIELD_NUMBER: builtins.int
        data_source: builtins.str
        def __init__(
            self,
            *,
            data_source: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["data_source", b"data_source"]) -> None: ...

    LAST9_FIELD_NUMBER: builtins.int
    @property
    def last9(self) -> global___AnnotationsConfig.Last9: ...
    def __init__(
        self,
        *,
        last9: global___AnnotationsConfig.Last9 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last9", b"last9"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last9", b"last9"]) -> None: ...

global___AnnotationsConfig = AnnotationsConfig

class ApplicationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    RELEASE_CHANNELS_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_GROUPS_FIELD_NUMBER: builtins.int
    NOTIFICATIONS_FIELD_NUMBER: builtins.int
    ANNOTATIONS_FIELD_NUMBER: builtins.int
    ALERTS_FIELD_NUMBER: builtins.int
    CAPABILITIES_FIELD_NUMBER: builtins.int
    CAPABILITY_INSTANCES_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def release_channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig]: ...
    @property
    def release_channel_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelGroupGeneratorConfig]: ...
    @property
    def notifications(self) -> prodvana.proto.prodvana.common_config.notification_pb2.NotificationConfig: ...
    @property
    def annotations(self) -> global___AnnotationsConfig: ...
    @property
    def alerts(self) -> prodvana.proto.prodvana.workflow.integration_config_pb2.AlertingConfig:
        """deprecated"""
    @property
    def capabilities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.capability.capability_pb2.CapabilityConfig]:
        """deprecated"""
    @property
    def capability_instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.capability.capability_pb2.CapabilityInstanceConfig]:
        """deprecated"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        release_channels: collections.abc.Iterable[prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig] | None = ...,
        release_channel_groups: collections.abc.Iterable[prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelGroupGeneratorConfig] | None = ...,
        notifications: prodvana.proto.prodvana.common_config.notification_pb2.NotificationConfig | None = ...,
        annotations: global___AnnotationsConfig | None = ...,
        alerts: prodvana.proto.prodvana.workflow.integration_config_pb2.AlertingConfig | None = ...,
        capabilities: collections.abc.Iterable[prodvana.proto.prodvana.capability.capability_pb2.CapabilityConfig] | None = ...,
        capability_instances: collections.abc.Iterable[prodvana.proto.prodvana.capability.capability_pb2.CapabilityInstanceConfig] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["alerts", b"alerts", "annotations", b"annotations", "notifications", b"notifications"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alerts", b"alerts", "annotations", b"annotations", "capabilities", b"capabilities", "capability_instances", b"capability_instances", "name", b"name", "notifications", b"notifications", "release_channel_groups", b"release_channel_groups", "release_channels", b"release_channels"]) -> None: ...

global___ApplicationConfig = ApplicationConfig



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/application/application_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.capability import capability_pb2 as prodvana_dot_capability_dot_capability__pb2
from prodvana.proto.prodvana.common_config import notification_pb2 as prodvana_dot_common__config_dot_notification__pb2
from prodvana.proto.prodvana.release_channel import release_channel_config_pb2 as prodvana_dot_release__channel_dot_release__channel__config__pb2
from prodvana.proto.prodvana.workflow import integration_config_pb2 as prodvana_dot_workflow_dot_integration__config__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-prodvana/application/application_config.proto\x12\x14prodvana.application\x1a$prodvana/capability/capability.proto\x1a)prodvana/common_config/notification.proto\x1a\x35prodvana/release_channel/release_channel_config.proto\x1a*prodvana/workflow/integration_config.proto\x1a\x17validate/validate.proto\"x\n\x11\x41nnotationsConfig\x12<\n\x05last9\x18\x01 \x01(\x0b\x32-.prodvana.application.AnnotationsConfig.Last9\x1a%\n\x05Last9\x12\x1c\n\x0b\x64\x61ta_source\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xdc\x05\n\x11\x41pplicationConfig\x12\x39\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$\x12H\n\x10release_channels\x18\x02 \x03(\x0b\x32..prodvana.release_channel.ReleaseChannelConfig\x12k\n\x16release_channel_groups\x18\x0b \x03(\x0b\x32<.prodvana.release_channel.ReleaseChannelGroupGeneratorConfigB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12\x41\n\rnotifications\x18\x04 \x01(\x0b\x32*.prodvana.common_config.NotificationConfig\x12<\n\x0b\x61nnotations\x18\x0c \x01(\x0b\x32\'.prodvana.application.AnnotationsConfig\x12\x31\n\x06\x61lerts\x18\x05 \x01(\x0b\x32!.prodvana.workflow.AlertingConfig\x12J\n\x0c\x63\x61pabilities\x18\x06 \x03(\x0b\x32%.prodvana.capability.CapabilityConfigB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12Z\n\x14\x63\x61pability_instances\x18\x07 \x03(\x0b\x32-.prodvana.capability.CapabilityInstanceConfigB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01J\x04\x08\x03\x10\x04J\x04\x08\x08\x10\tJ\x04\x08\t\x10\nJ\x04\x08\n\x10\x0bR\x11service_templatesR\x12pipeline_templatesR\x14use_dynamic_deliveryR$enable_custom_tasks_dynamic_deliveryBPZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/applicationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.application.application_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/application'
  _ANNOTATIONSCONFIG_LAST9.fields_by_name['data_source']._options = None
  _ANNOTATIONSCONFIG_LAST9.fields_by_name['data_source']._serialized_options = b'\372B\004r\002\020\001'
  _APPLICATIONCONFIG.fields_by_name['name']._options = None
  _APPLICATIONCONFIG.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$'
  _APPLICATIONCONFIG.fields_by_name['release_channel_groups']._options = None
  _APPLICATIONCONFIG.fields_by_name['release_channel_groups']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _APPLICATIONCONFIG.fields_by_name['capabilities']._options = None
  _APPLICATIONCONFIG.fields_by_name['capabilities']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _APPLICATIONCONFIG.fields_by_name['capability_instances']._options = None
  _APPLICATIONCONFIG.fields_by_name['capability_instances']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _globals['_ANNOTATIONSCONFIG']._serialized_start=276
  _globals['_ANNOTATIONSCONFIG']._serialized_end=396
  _globals['_ANNOTATIONSCONFIG_LAST9']._serialized_start=359
  _globals['_ANNOTATIONSCONFIG_LAST9']._serialized_end=396
  _globals['_APPLICATIONCONFIG']._serialized_start=399
  _globals['_APPLICATIONCONFIG']._serialized_end=1131
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class DebugEvent(google.protobuf.message.Message):
    """An event useful in explaining the status of the Runtime object.
    Events are not guaranteed to be stable and may differ depending on the
    current status of the Runtime object.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMESTAMP_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    message: builtins.str
    def __init__(
        self,
        *,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        message: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message", "timestamp", b"timestamp"]) -> None: ...

global___DebugEvent = DebugEvent



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/helm.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.common_config import kubernetes_config_pb2 as prodvana_dot_common__config_dot_kubernetes__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!prodvana/common_config/helm.proto\x12\x16prodvana.common_config\x1a\x17validate/validate.proto\x1a.prodvana/common_config/kubernetes_config.proto\"l\n\x0fRemoteHelmChart\x12\x0e\n\x04repo\x18\x01 \x01(\tH\x00\x12\x16\n\x05\x63hart\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1e\n\rchart_version\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\x11\n\nrepo_oneof\x12\x03\xf8\x42\x01\"\xc1\x01\n\x13HelmValuesOverrides\x12\x1a\n\x07inlined\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x34\n\x05local\x18\x02 \x01(\x0b\x32#.prodvana.common_config.LocalConfigH\x00\x12\x36\n\x06remote\x18\x04 \x01(\x0b\x32$.prodvana.common_config.RemoteConfigH\x00\x42\x15\n\x0eoverride_oneof\x12\x03\xf8\x42\x01J\x04\x08\x03\x10\x04R\x03map\"\xd0\x02\n\nHelmConfig\x12\x39\n\x06remote\x18\x01 \x01(\x0b\x32\'.prodvana.common_config.RemoteHelmChartH\x00\x12\x34\n\x05local\x18\x05 \x01(\x0b\x32#.prodvana.common_config.LocalConfigH\x00\x12\x1e\n\x14helm_tarball_blob_id\x18\x06 \x01(\tH\x00\x12\x45\n\x10values_overrides\x18\x02 \x03(\x0b\x32+.prodvana.common_config.HelmValuesOverrides\x12\x14\n\x0crelease_name\x18\x03 \x01(\t\x12\x1a\n\tnamespace\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x18\x00\x12\x17\n\x0f\x66ixup_ownership\x18\x08 \x01(\x08\x42\x12\n\x0b\x63hart_oneof\x12\x03\xf8\x42\x01J\x04\x08\x07\x10\x08R\x05\x66orceBRZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.common_config.helm_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _REMOTEHELMCHART.oneofs_by_name['repo_oneof']._options = None
  _REMOTEHELMCHART.oneofs_by_name['repo_oneof']._serialized_options = b'\370B\001'
  _REMOTEHELMCHART.fields_by_name['chart']._options = None
  _REMOTEHELMCHART.fields_by_name['chart']._serialized_options = b'\372B\004r\002\020\001'
  _REMOTEHELMCHART.fields_by_name['chart_version']._options = None
  _REMOTEHELMCHART.fields_by_name['chart_version']._serialized_options = b'\372B\004r\002\020\001'
  _HELMVALUESOVERRIDES.oneofs_by_name['override_oneof']._options = None
  _HELMVALUESOVERRIDES.oneofs_by_name['override_oneof']._serialized_options = b'\370B\001'
  _HELMVALUESOVERRIDES.fields_by_name['inlined']._options = None
  _HELMVALUESOVERRIDES.fields_by_name['inlined']._serialized_options = b'\372B\004r\002\020\001'
  _HELMCONFIG.oneofs_by_name['chart_oneof']._options = None
  _HELMCONFIG.oneofs_by_name['chart_oneof']._serialized_options = b'\370B\001'
  _HELMCONFIG.fields_by_name['namespace']._options = None
  _HELMCONFIG.fields_by_name['namespace']._serialized_options = b'\372B\004r\002\030\000'
  _globals['_REMOTEHELMCHART']._serialized_start=134
  _globals['_REMOTEHELMCHART']._serialized_end=242
  _globals['_HELMVALUESOVERRIDES']._serialized_start=245
  _globals['_HELMVALUESOVERRIDES']._serialized_end=438
  _globals['_HELMCONFIG']._serialized_start=441
  _globals['_HELMCONFIG']._serialized_end=777
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FeatureType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FeatureTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FeatureType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _FeatureType.ValueType  # 0
    EXPOSED_SERVICE: _FeatureType.ValueType  # 1
    TLS_SERVICE: _FeatureType.ValueType  # 2
    COST_ANALYSIS: _FeatureType.ValueType  # 3
    DATADOG: _FeatureType.ValueType  # 4
    ARGO_ROLLOUTS: _FeatureType.ValueType  # 5

class FeatureType(_FeatureType, metaclass=_FeatureTypeEnumTypeWrapper): ...

UNKNOWN: FeatureType.ValueType  # 0
EXPOSED_SERVICE: FeatureType.ValueType  # 1
TLS_SERVICE: FeatureType.ValueType  # 2
COST_ANALYSIS: FeatureType.ValueType  # 3
DATADOG: FeatureType.ValueType  # 4
ARGO_ROLLOUTS: FeatureType.ValueType  # 5
global___FeatureType = FeatureType



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.labels.labels_pb2
import prodvana.proto.prodvana.object.meta_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class QueryObjectReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    query: builtins.str
    def __init__(
        self,
        *,
        query: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["query", b"query"]) -> None: ...

global___QueryObjectReq = QueryObjectReq

class QueryObjectResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECTS_FIELD_NUMBER: builtins.int
    @property
    def objects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.object.meta_pb2.ObjectMeta]: ...
    def __init__(
        self,
        *,
        objects: collections.abc.Iterable[prodvana.proto.prodvana.object.meta_pb2.ObjectMeta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["objects", b"objects"]) -> None: ...

global___QueryObjectResp = QueryObjectResp

class GetLabelsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    type: prodvana.proto.prodvana.object.meta_pb2.ObjectType.ValueType
    id: builtins.str
    def __init__(
        self,
        *,
        type: prodvana.proto.prodvana.object.meta_pb2.ObjectType.ValueType = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "type", b"type"]) -> None: ...

global___GetLabelsReq = GetLabelsReq

class GetLabelsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABELS_FIELD_NUMBER: builtins.int
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.labels.labels_pb2.LabelDefinition]: ...
    def __init__(
        self,
        *,
        labels: collections.abc.Iterable[prodvana.proto.prodvana.labels.labels_pb2.LabelDefinition] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["labels", b"labels"]) -> None: ...

global___GetLabelsResp = GetLabelsResp



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.environment.environment_manager_pb2

class EnvironmentManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetClusterAgentApiToken: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterAgentApiTokenReq,
        prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterAgentApiTokenResp,
    ]
    LinkCluster: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.environment.environment_manager_pb2.LinkClusterReq,
        prodvana.proto.prodvana.environment.environment_manager_pb2.LinkClusterResp,
    ]
    ListClusters: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.environment.environment_manager_pb2.ListClustersReq,
        prodvana.proto.prodvana.environment.environment_manager_pb2.ListClustersResp,
    ]
    GetCluster: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterReq,
        prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterResp,
    ]
    RemoveCluster: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.environment.environment_manager_pb2.RemoveClusterReq,
        prodvana.proto.prodvana.environment.environment_manager_pb2.RemoveClusterResp,
    ]
    GetClusterAuth: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterAuthReq,
        prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterAuthResp,
    ]
    """Deprecated."""
    GetClusterConfig: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterConfigReq,
        prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterConfigResp,
    ]
    DetectClusterConfig: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.environment.environment_manager_pb2.DetectClusterConfigReq,
        prodvana.proto.prodvana.environment.environment_manager_pb2.DetectClusterConfigResp,
    ]
    ConfigureCluster: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.environment.environment_manager_pb2.ConfigureClusterReq,
        prodvana.proto.prodvana.environment.environment_manager_pb2.ConfigureClusterResp,
    ]
    ValidateConfigureCluster: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.environment.environment_manager_pb2.ConfigureClusterReq,
        prodvana.proto.prodvana.environment.environment_manager_pb2.ValidateConfigureClusterResp,
    ]
    GetClusterStatus: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterStatusReq,
        prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterStatusResp,
    ]
    PauseCluster: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.environment.environment_manager_pb2.PauseClusterReq,
        prodvana.proto.prodvana.environment.environment_manager_pb2.PauseClusterResp,
    ]
    ResumeCluster: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.environment.environment_manager_pb2.ResumeClusterReq,
        prodvana.proto.prodvana.environment.environment_manager_pb2.ResumeClusterResp,
    ]

class EnvironmentManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetClusterAgentApiToken(
        self,
        request: prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterAgentApiTokenReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterAgentApiTokenResp: ...
    @abc.abstractmethod
    def LinkCluster(
        self,
        request: prodvana.proto.prodvana.environment.environment_manager_pb2.LinkClusterReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.environment.environment_manager_pb2.LinkClusterResp: ...
    @abc.abstractmethod
    def ListClusters(
        self,
        request: prodvana.proto.prodvana.environment.environment_manager_pb2.ListClustersReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.environment.environment_manager_pb2.ListClustersResp: ...
    @abc.abstractmethod
    def GetCluster(
        self,
        request: prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterResp: ...
    @abc.abstractmethod
    def RemoveCluster(
        self,
        request: prodvana.proto.prodvana.environment.environment_manager_pb2.RemoveClusterReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.environment.environment_manager_pb2.RemoveClusterResp: ...
    @abc.abstractmethod
    def GetClusterAuth(
        self,
        request: prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterAuthReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterAuthResp:
        """Deprecated."""
    @abc.abstractmethod
    def GetClusterConfig(
        self,
        request: prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterConfigReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterConfigResp: ...
    @abc.abstractmethod
    def DetectClusterConfig(
        self,
        request: prodvana.proto.prodvana.environment.environment_manager_pb2.DetectClusterConfigReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.environment.environment_manager_pb2.DetectClusterConfigResp: ...
    @abc.abstractmethod
    def ConfigureCluster(
        self,
        request: prodvana.proto.prodvana.environment.environment_manager_pb2.ConfigureClusterReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.environment.environment_manager_pb2.ConfigureClusterResp: ...
    @abc.abstractmethod
    def ValidateConfigureCluster(
        self,
        request: prodvana.proto.prodvana.environment.environment_manager_pb2.ConfigureClusterReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.environment.environment_manager_pb2.ValidateConfigureClusterResp: ...
    @abc.abstractmethod
    def GetClusterStatus(
        self,
        request: prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterStatusReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.environment.environment_manager_pb2.GetClusterStatusResp: ...
    @abc.abstractmethod
    def PauseCluster(
        self,
        request: prodvana.proto.prodvana.environment.environment_manager_pb2.PauseClusterReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.environment.environment_manager_pb2.PauseClusterResp: ...
    @abc.abstractmethod
    def ResumeCluster(
        self,
        request: prodvana.proto.prodvana.environment.environment_manager_pb2.ResumeClusterReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.environment.environment_manager_pb2.ResumeClusterResp: ...

def add_EnvironmentManagerServicer_to_server(servicer: EnvironmentManagerServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.common_config.task_pb2
import prodvana.proto.prodvana.desired_state.model.desired_state_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DependencyType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DependencyTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DependencyType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEPENDENCY_UNKNOWN: _DependencyType.ValueType  # 0
    DEPENDENCY_CHILD: _DependencyType.ValueType  # 1
    DEPENDENCY_PROTECTION_ATTACHMENT: _DependencyType.ValueType  # 2
    DEPENDENCY_RELEASE_CHANNEL: _DependencyType.ValueType  # 3
    DEPENDENCY_PRECONDITION: _DependencyType.ValueType  # 4
    DEPENDENCY_DELIVERY_EXTENSION: _DependencyType.ValueType  # 5

class DependencyType(_DependencyType, metaclass=_DependencyTypeEnumTypeWrapper): ...

DEPENDENCY_UNKNOWN: DependencyType.ValueType  # 0
DEPENDENCY_CHILD: DependencyType.ValueType  # 1
DEPENDENCY_PROTECTION_ATTACHMENT: DependencyType.ValueType  # 2
DEPENDENCY_RELEASE_CHANNEL: DependencyType.ValueType  # 3
DEPENDENCY_PRECONDITION: DependencyType.ValueType  # 4
DEPENDENCY_DELIVERY_EXTENSION: DependencyType.ValueType  # 5
global___DependencyType = DependencyType

class Notifications(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ProgramFailures(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FAILURE_COUNT_FIELD_NUMBER: builtins.int
        MOST_RECENT_FAILURE_FIELD_NUMBER: builtins.int
        failure_count: builtins.int
        """Either k8s errors or runtime extension apply errors"""
        @property
        def most_recent_failure(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            failure_count: builtins.int = ...,
            most_recent_failure: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["most_recent_failure", b"most_recent_failure"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["failure_count", b"failure_count", "most_recent_failure", b"most_recent_failure"]) -> None: ...

    class RuntimeFailure(google.protobuf.message.Message):
        """Info to convey:
        - Extension Fetch couldn't be started - kubernetes errors?
        - Extension Fetch ran but failed
        - K8s apply error
        - Extension Apply couldn't be applied
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _FailureType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _FailureTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Notifications.RuntimeFailure._FailureType.ValueType], builtins.type):  # noqa: F821
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            UNKNOWN: Notifications.RuntimeFailure._FailureType.ValueType  # 0
            EXTENSION_FETCH_INVOKE_ERROR: Notifications.RuntimeFailure._FailureType.ValueType  # 1
            EXTENSION_FETCH_RESULT_ERROR: Notifications.RuntimeFailure._FailureType.ValueType  # 2
            RUNTIME_APPLY_ERROR: Notifications.RuntimeFailure._FailureType.ValueType  # 3
            EXTENSION_APPLY_INVOKE_ERROR: Notifications.RuntimeFailure._FailureType.ValueType  # 4

        class FailureType(_FailureType, metaclass=_FailureTypeEnumTypeWrapper): ...
        UNKNOWN: Notifications.RuntimeFailure.FailureType.ValueType  # 0
        EXTENSION_FETCH_INVOKE_ERROR: Notifications.RuntimeFailure.FailureType.ValueType  # 1
        EXTENSION_FETCH_RESULT_ERROR: Notifications.RuntimeFailure.FailureType.ValueType  # 2
        RUNTIME_APPLY_ERROR: Notifications.RuntimeFailure.FailureType.ValueType  # 3
        EXTENSION_APPLY_INVOKE_ERROR: Notifications.RuntimeFailure.FailureType.ValueType  # 4

        FAILURE_TYPE_FIELD_NUMBER: builtins.int
        MESSAGE_FIELD_NUMBER: builtins.int
        failure_type: global___Notifications.RuntimeFailure.FailureType.ValueType
        message: builtins.str
        """TODO: Indicate event id if possible"""
        def __init__(
            self,
            *,
            failure_type: global___Notifications.RuntimeFailure.FailureType.ValueType = ...,
            message: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["failure_type", b"failure_type", "message", b"message"]) -> None: ...

    class ProtectionFailure(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PROTECTION_ID_FIELD_NUMBER: builtins.int
        @property
        def protection_id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
        def __init__(
            self,
            *,
            protection_id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["protection_id", b"protection_id"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["protection_id", b"protection_id"]) -> None: ...

    class ConvergenceExtensionFailure(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EXTENSION_ID_FIELD_NUMBER: builtins.int
        @property
        def extension_id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
        def __init__(
            self,
            *,
            extension_id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["extension_id", b"extension_id"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["extension_id", b"extension_id"]) -> None: ...

    class DelayedConvergence(google.protobuf.message.Message):
        """- Runtime extension fetch has not completed a long time after it was started"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    PROGRAM_FAILURES_FIELD_NUMBER: builtins.int
    RUNTIME_FAILURES_FIELD_NUMBER: builtins.int
    PROTECTION_FAILURE_FIELD_NUMBER: builtins.int
    CONVERGENCE_EXTENSION_FAILURE_FIELD_NUMBER: builtins.int
    DELAYED_CONVERGENCE_FIELD_NUMBER: builtins.int
    CONCURRENCY_LIMIT_EXCEEDED_ERRORS_FIELD_NUMBER: builtins.int
    @property
    def program_failures(self) -> global___Notifications.ProgramFailures: ...
    @property
    def runtime_failures(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Notifications.RuntimeFailure]: ...
    @property
    def protection_failure(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Notifications.ProtectionFailure]: ...
    @property
    def convergence_extension_failure(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Notifications.ConvergenceExtensionFailure]: ...
    @property
    def delayed_convergence(self) -> global___Notifications.DelayedConvergence: ...
    @property
    def concurrency_limit_exceeded_errors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ConcurrencyLimitExceeded]:
        """TODO: Link to next action?"""
    def __init__(
        self,
        *,
        program_failures: global___Notifications.ProgramFailures | None = ...,
        runtime_failures: collections.abc.Iterable[global___Notifications.RuntimeFailure] | None = ...,
        protection_failure: collections.abc.Iterable[global___Notifications.ProtectionFailure] | None = ...,
        convergence_extension_failure: collections.abc.Iterable[global___Notifications.ConvergenceExtensionFailure] | None = ...,
        delayed_convergence: global___Notifications.DelayedConvergence | None = ...,
        concurrency_limit_exceeded_errors: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ConcurrencyLimitExceeded] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delayed_convergence", b"delayed_convergence", "program_failures", b"program_failures"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["concurrency_limit_exceeded_errors", b"concurrency_limit_exceeded_errors", "convergence_extension_failure", b"convergence_extension_failure", "delayed_convergence", b"delayed_convergence", "program_failures", b"program_failures", "protection_failure", b"protection_failure", "runtime_failures", b"runtime_failures"]) -> None: ...

global___Notifications = Notifications

class Dependency(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    type: global___DependencyType.ValueType
    @property
    def id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    def __init__(
        self,
        *,
        type: global___DependencyType.ValueType = ...,
        id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["id", b"id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "type", b"type"]) -> None: ...

global___Dependency = Dependency

class Entity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ROOT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    PARENT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    RELEASE_ID_FIELD_NUMBER: builtins.int
    ANNOTATIONS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SIMPLE_STATUS_FIELD_NUMBER: builtins.int
    STARTING_STATE_FIELD_NUMBER: builtins.int
    LAST_SEEN_STATE_FIELD_NUMBER: builtins.int
    DESIRED_STATE_FIELD_NUMBER: builtins.int
    TARGET_STATE_FIELD_NUMBER: builtins.int
    PRECONDITION_STATUSES_FIELD_NUMBER: builtins.int
    STATUS_EXPLANATIONS_FIELD_NUMBER: builtins.int
    LOGS_FIELD_NUMBER: builtins.int
    ACTION_EXPLANATION_FIELD_NUMBER: builtins.int
    LAST_UPDATE_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_FETCHED_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_APPLIED_TIMESTAMP_FIELD_NUMBER: builtins.int
    EXPECTED_NEXT_APPLY_TIMESTAMP_FIELD_NUMBER: builtins.int
    DEPENDENCIES_FIELD_NUMBER: builtins.int
    DIRECT_DEPENDENCIES_FIELD_NUMBER: builtins.int
    DEPENDENCIES_WITH_TYPE_FIELD_NUMBER: builtins.int
    LIFECYCLE_FIELD_NUMBER: builtins.int
    MISSING_APPROVAL_FIELD_NUMBER: builtins.int
    APPLY_ERROR_FIELD_NUMBER: builtins.int
    NOTIFICATIONS_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    desired_state_id: builtins.str
    root_desired_state_id: builtins.str
    parent_desired_state_id: builtins.str
    release_id: builtins.str
    @property
    def annotations(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Annotations: ...
    status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType
    simple_status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.SimpleStatus.ValueType
    @property
    def starting_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def last_seen_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """the state we want to get to before calling convergence complete"""
    @property
    def target_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """the state we are actually going to apply. when preconditions are met, target state = desired state, otherwise, target state = previous desired state"""
    @property
    def precondition_statuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ConditionState]: ...
    @property
    def status_explanations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation]: ...
    @property
    def logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DebugLog]: ...
    @property
    def action_explanation(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ActionExplanation: ...
    @property
    def last_update_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """when the entity state last changed"""
    @property
    def last_fetched_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """when prodvana last fetched entity state, best effort"""
    @property
    def last_applied_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """when prodvana last applied state for this entity, best effort"""
    @property
    def expected_next_apply_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """when prodvana expects to run apply again for this entity, if there is any work to be done. If nil, apply is expected to happen immediately, again if there is any work to be done."""
    @property
    def dependencies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier]: ...
    @property
    def direct_dependencies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier]: ...
    @property
    def dependencies_with_type(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Dependency]: ...
    lifecycle: prodvana.proto.prodvana.common_config.task_pb2.TaskLifecycle.ValueType
    @property
    def missing_approval(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.MissingApproval: ...
    @property
    def apply_error(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ApplyError: ...
    @property
    def notifications(self) -> global___Notifications: ...
    def __init__(
        self,
        *,
        id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        desired_state_id: builtins.str = ...,
        root_desired_state_id: builtins.str = ...,
        parent_desired_state_id: builtins.str = ...,
        release_id: builtins.str = ...,
        annotations: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Annotations | None = ...,
        status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType = ...,
        simple_status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.SimpleStatus.ValueType = ...,
        starting_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        last_seen_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        target_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        precondition_statuses: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ConditionState] | None = ...,
        status_explanations: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation] | None = ...,
        logs: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DebugLog] | None = ...,
        action_explanation: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ActionExplanation | None = ...,
        last_update_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_fetched_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_applied_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        expected_next_apply_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        dependencies: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier] | None = ...,
        direct_dependencies: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier] | None = ...,
        dependencies_with_type: collections.abc.Iterable[global___Dependency] | None = ...,
        lifecycle: prodvana.proto.prodvana.common_config.task_pb2.TaskLifecycle.ValueType = ...,
        missing_approval: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.MissingApproval | None = ...,
        apply_error: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ApplyError | None = ...,
        notifications: global___Notifications | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action_explanation", b"action_explanation", "annotations", b"annotations", "apply_error", b"apply_error", "desired_state", b"desired_state", "expected_next_apply_timestamp", b"expected_next_apply_timestamp", "id", b"id", "last_applied_timestamp", b"last_applied_timestamp", "last_fetched_timestamp", b"last_fetched_timestamp", "last_seen_state", b"last_seen_state", "last_update_timestamp", b"last_update_timestamp", "missing_approval", b"missing_approval", "notifications", b"notifications", "starting_state", b"starting_state", "target_state", b"target_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_explanation", b"action_explanation", "annotations", b"annotations", "apply_error", b"apply_error", "dependencies", b"dependencies", "dependencies_with_type", b"dependencies_with_type", "desired_state", b"desired_state", "desired_state_id", b"desired_state_id", "direct_dependencies", b"direct_dependencies", "expected_next_apply_timestamp", b"expected_next_apply_timestamp", "id", b"id", "last_applied_timestamp", b"last_applied_timestamp", "last_fetched_timestamp", b"last_fetched_timestamp", "last_seen_state", b"last_seen_state", "last_update_timestamp", b"last_update_timestamp", "lifecycle", b"lifecycle", "logs", b"logs", "missing_approval", b"missing_approval", "notifications", b"notifications", "parent_desired_state_id", b"parent_desired_state_id", "precondition_statuses", b"precondition_statuses", "release_id", b"release_id", "root_desired_state_id", b"root_desired_state_id", "simple_status", b"simple_status", "starting_state", b"starting_state", "status", b"status", "status_explanations", b"status_explanations", "target_state", b"target_state"]) -> None: ...

global___Entity = Entity

class EntityGraph(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOT_FIELD_NUMBER: builtins.int
    ENTITIES_FIELD_NUMBER: builtins.int
    @property
    def root(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    @property
    def entities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Entity]: ...
    def __init__(
        self,
        *,
        root: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        entities: collections.abc.Iterable[global___Entity] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["root", b"root"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entities", b"entities", "root", b"root"]) -> None: ...

global___EntityGraph = EntityGraph



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import prodvana.proto.prodvana.common_config.kubernetes_config_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class FlyConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INLINED_FIELD_NUMBER: builtins.int
    LOCAL_FIELD_NUMBER: builtins.int
    REMOTE_FIELD_NUMBER: builtins.int
    inlined: builtins.str
    @property
    def local(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.LocalConfig: ...
    @property
    def remote(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.RemoteConfig: ...
    def __init__(
        self,
        *,
        inlined: builtins.str = ...,
        local: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.LocalConfig | None = ...,
        remote: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.RemoteConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["inlined", b"inlined", "local", b"local", "remote", b"remote", "toml_oneof", b"toml_oneof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["inlined", b"inlined", "local", b"local", "remote", b"remote", "toml_oneof", b"toml_oneof"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["toml_oneof", b"toml_oneof"]) -> typing_extensions.Literal["inlined", "local", "remote"] | None: ...

global___FlyConfig = FlyConfig
